UserId

Struct UserId 

pub struct UserId { /* private fields */ }
A unique identifier for a User within an Agent’s domain. https://gitlab.com/relay-mail/docs/-/wikis/Architecture/Identity#user-identity

Implementations

Source

impl UserId

pub fn parse(input: impl AsRef<str>) -> Result<UserId, IdentityError>

Parse a UserId from a string according to the identity rules. https://gitlab.com/relay-mail/docs/-/wikis/Architecture/Identity#user-identity

Examples
let user_id = relay_core::id::UserId::parse("Alice.Smith").unwrap();
assert_eq!(user_id.canonical(), "#alice.smith");
let user_id = relay_core::id::UserId::parse("Work#Alice.Smith").unwrap();
assert_eq!(user_id.canonical(), "work#alice.smith");
pub fn replace( &mut self, new_value: impl AsRef<str>, ) -> Result<(), IdentityError>

Replace the current UserId with a new value.

pub fn inbox(&self) -> Option<&InboxId>

Get the inbox.

pub fn canonical(&self) -> String

The canonical form of the UserId. The value is already stored as such. https://gitlab.com/relay-mail/docs/-/wikis/Architecture/Identity#canonical-form